# Org.OpenAPITools - the C# library for the Chat API SDK

The SDK allows you to receive and send messages through your WhatsApp account. [Sign up now](https://app.chat-api.com/)  The Chat API is based on the WhatsApp WEB protocol and excludes the ban both when using libraries from mgp25 and the like. Despite this, your account can be banned by anti-spam system WhatsApp after several clicking the \"block\" button.

This C# SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- SDK version: 1.0.0
- Build package: org.openapitools.codegen.languages.CSharpClientCodegen

## Frameworks supported


- .NET 4.0 or later
- Windows Phone 7.1 (Mango)

## Dependencies


- [RestSharp](https://www.nuget.org/packages/RestSharp) - 105.1.0 or later
- [Json.NET](https://www.nuget.org/packages/Newtonsoft.Json/) - 7.0.0 or later
- [JsonSubTypes](https://www.nuget.org/packages/JsonSubTypes/) - 1.2.0 or later

The DLLs included in the package may not be the latest version. We recommend using [NuGet](https://docs.nuget.org/consume/installing-nuget) to obtain the latest version of the packages:

```
Install-Package RestSharp
Install-Package Newtonsoft.Json
Install-Package JsonSubTypes
```

NOTE: RestSharp versions greater than 105.1.0 have a bug which causes file uploads to fail. See [RestSharp#742](https://github.com/restsharp/RestSharp/issues/742)

## Installation

Run the following command to generate the DLL

- [Mac/Linux] `/bin/sh build.sh`
- [Windows] `build.bat`

Then include the DLL (under the `bin` folder) in the C# project, and use the namespaces:

```csharp
using Org.OpenAPITools.Api;
using Org.OpenAPITools.Client;
using Org.OpenAPITools.Model;

```


## Packaging

A `.nuspec` is included with the project. You can follow the Nuget quickstart to [create](https://docs.microsoft.com/en-us/nuget/quickstart/create-and-publish-a-package#create-the-package) and [publish](https://docs.microsoft.com/en-us/nuget/quickstart/create-and-publish-a-package#publish-the-package) packages.

This `.nuspec` uses placeholders from the `.csproj`, so build the `.csproj` directly:

```
nuget pack -Build -OutputDirectory out Org.OpenAPITools.csproj
```

Then, publish to a [local feed](https://docs.microsoft.com/en-us/nuget/hosting-packages/local-feeds) or [other host](https://docs.microsoft.com/en-us/nuget/hosting-packages/overview) and consume the new package via Nuget as usual.


## Getting Started

```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Org.OpenAPITools.Api;
using Org.OpenAPITools.Client;
using Org.OpenAPITools.Model;

namespace Example
{
    public class Example
    {
        public static void Main()
        {

            Configuration.Default.BasePath = "https://api.chat-api.com";
            // Configure API key authorization: instanceId
            Configuration.Default.ApiKey.Add("instanceId", "YOUR_API_KEY");
            // Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
            // Configuration.Default.ApiKeyPrefix.Add("instanceId", "Bearer");
            // Configure API key authorization: token
            Configuration.Default.ApiKey.Add("token", "YOUR_API_KEY");
            // Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
            // Configuration.Default.ApiKeyPrefix.Add("token", "Bearer");

            var apiInstance = new Class1InstanceApi(Configuration.Default);

            try
            {
                // Updates the QR code after its expired
                InlineResponse2002 result = apiInstance.Expiry();
                Debug.WriteLine(result);
            }
            catch (ApiException e)
            {
                Debug.Print("Exception when calling Class1InstanceApi.Expiry: " + e.Message );
                Debug.Print("Status Code: "+ e.ErrorCode);
                Debug.Print(e.StackTrace);
            }

        }
    }
}
```

## Documentation for API Endpoints

All URIs are relative to *https://api.chat-api.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*Class1InstanceApi* | [**Expiry**](docs/Class1InstanceApi.md#expiry) | **POST** /expiry | Updates the QR code after its expired
*Class1InstanceApi* | [**GetQRCode**](docs/Class1InstanceApi.md#getqrcode) | **GET** /qr_code | Direct link to QR-code in the form of an image, not base64.
*Class1InstanceApi* | [**GetSettings**](docs/Class1InstanceApi.md#getsettings) | **GET** /settings | Get settings
*Class1InstanceApi* | [**GetStatus**](docs/Class1InstanceApi.md#getstatus) | **GET** /status | Get the account status and QR code for authorization.
*Class1InstanceApi* | [**Logout**](docs/Class1InstanceApi.md#logout) | **POST** /logout | Logout from WhatsApp Web to get new QR code.
*Class1InstanceApi* | [**Reboot**](docs/Class1InstanceApi.md#reboot) | **POST** /reboot | Reboot your whatsapp instance.
*Class1InstanceApi* | [**Retry**](docs/Class1InstanceApi.md#retry) | **POST** /retry | Repeat the manual synchronization attempt with the device
*Class1InstanceApi* | [**SetSettings**](docs/Class1InstanceApi.md#setsettings) | **POST** /settings | Set settings
*Class1InstanceApi* | [**Takeover**](docs/Class1InstanceApi.md#takeover) | **POST** /takeover | Returns the active session if the device has connected another instance of Web WhatsApp
*Class2MessagesApi* | [**ForwardMessage**](docs/Class2MessagesApi.md#forwardmessage) | **POST** /forwardMessage | Forwarding messages to a new or existing chat.
*Class2MessagesApi* | [**GetMessages**](docs/Class2MessagesApi.md#getmessages) | **GET** /messages | Get a list of messages.
*Class2MessagesApi* | [**SendContact**](docs/Class2MessagesApi.md#sendcontact) | **POST** /sendContact | Sending a contact or contact list to a new or existing chat.
*Class2MessagesApi* | [**SendFile**](docs/Class2MessagesApi.md#sendfile) | **POST** /sendFile | Send a file to a new or existing chat.
*Class2MessagesApi* | [**SendLink**](docs/Class2MessagesApi.md#sendlink) | **POST** /sendLink | Send text with link and link's preview to a new or existing chat.
*Class2MessagesApi* | [**SendLocation**](docs/Class2MessagesApi.md#sendlocation) | **POST** /sendLocation | Sending a location to a new or existing chat.
*Class2MessagesApi* | [**SendMessage**](docs/Class2MessagesApi.md#sendmessage) | **POST** /sendMessage | Send a message to a new or existing chat.
*Class2MessagesApi* | [**SendPTT**](docs/Class2MessagesApi.md#sendptt) | **POST** /sendPTT | Send a ptt-audio to a new or existing chat.
*Class2MessagesApi* | [**SendVCard**](docs/Class2MessagesApi.md#sendvcard) | **POST** /sendVCard | Sending a vcard to a new or existing chat.
*Class3ChatsApi* | [**AddGroupParticipant**](docs/Class3ChatsApi.md#addgroupparticipant) | **POST** /addGroupParticipant | Adding participant to a group
*Class3ChatsApi* | [**DemoteGroupParticipant**](docs/Class3ChatsApi.md#demotegroupparticipant) | **POST** /demoteGroupParticipant | Demote group participant
*Class3ChatsApi* | [**GetChats**](docs/Class3ChatsApi.md#getchats) | **GET** /dialogs | Get the chat list.
*Class3ChatsApi* | [**Group**](docs/Class3ChatsApi.md#group) | **POST** /group | Creates a group and sends the message to the created group.
*Class3ChatsApi* | [**PromoteGroupParticipant**](docs/Class3ChatsApi.md#promotegroupparticipant) | **POST** /promoteGroupParticipant | Make participant in the group an administrator
*Class3ChatsApi* | [**ReadChat**](docs/Class3ChatsApi.md#readchat) | **POST** /readChat | Open chat for reading messages
*Class3ChatsApi* | [**RemoveGroupParticipant**](docs/Class3ChatsApi.md#removegroupparticipant) | **POST** /removeGroupParticipant | Remove participant from a group
*Class4WebhooksApi* | [**SetWebhook**](docs/Class4WebhooksApi.md#setwebhook) | **POST** /webhook | Sets the URL for receiving webhook
*Class5QueuesApi* | [**ClearActionsQueue**](docs/Class5QueuesApi.md#clearactionsqueue) | **POST** /clearActionsQueue | Clear outbound actions queue.
*Class5QueuesApi* | [**ClearMessagesQueue**](docs/Class5QueuesApi.md#clearmessagesqueue) | **POST** /clearMessagesQueue | Clear outbound messages queue.
*Class5QueuesApi* | [**ShowActionsQueue**](docs/Class5QueuesApi.md#showactionsqueue) | **GET** /showActionsQueue | Get outbound messages queue.
*Class5QueuesApi* | [**ShowMessagesQueue**](docs/Class5QueuesApi.md#showmessagesqueue) | **GET** /showMessagesQueue | Get outbound messages queue.
*Class6BanApi* | [**BanTest**](docs/Class6BanApi.md#bantest) | **POST** /banTest | Test ban settings
*Class6BanApi* | [**GetBanSettings**](docs/Class6BanApi.md#getbansettings) | **GET** /banSettings | Get settings
*Class6BanApi* | [**SetBanSettings**](docs/Class6BanApi.md#setbansettings) | **POST** /banSettings | Set settings
*Class7TestingApi* | [**InstanceStatuses**](docs/Class7TestingApi.md#instancestatuses) | **GET** /instanceStatuses | Returns instance status changes history.
*Class7TestingApi* | [**WebhookStatuses**](docs/Class7TestingApi.md#webhookstatuses) | **GET** /webhookStatus | Returns webhook status for message.


## Documentation for Models

 - [Model.Ack](docs/Ack.md)
 - [Model.BanSettings](docs/BanSettings.md)
 - [Model.BanTestAction](docs/BanTestAction.md)
 - [Model.BanTestStatus](docs/BanTestStatus.md)
 - [Model.Chat](docs/Chat.md)
 - [Model.ChatIdProp](docs/ChatIdProp.md)
 - [Model.ChatUpdate](docs/ChatUpdate.md)
 - [Model.Chats](docs/Chats.md)
 - [Model.ClearActionsQueueStatus](docs/ClearActionsQueueStatus.md)
 - [Model.ClearMessagesQueueStatus](docs/ClearMessagesQueueStatus.md)
 - [Model.CreateGroupAction](docs/CreateGroupAction.md)
 - [Model.CreateGroupStatus](docs/CreateGroupStatus.md)
 - [Model.ForwardMessageRequest](docs/ForwardMessageRequest.md)
 - [Model.GroupParticipantAction](docs/GroupParticipantAction.md)
 - [Model.GroupParticipantStatus](docs/GroupParticipantStatus.md)
 - [Model.InlineResponse200](docs/InlineResponse200.md)
 - [Model.InlineResponse2001](docs/InlineResponse2001.md)
 - [Model.InlineResponse2002](docs/InlineResponse2002.md)
 - [Model.InlineResponse2003](docs/InlineResponse2003.md)
 - [Model.InlineResponse2004](docs/InlineResponse2004.md)
 - [Model.InlineResponse2005](docs/InlineResponse2005.md)
 - [Model.InlineResponse2005Update](docs/InlineResponse2005Update.md)
 - [Model.InlineResponse401](docs/InlineResponse401.md)
 - [Model.InstanceStatus](docs/InstanceStatus.md)
 - [Model.InstanceStatusAction](docs/InstanceStatusAction.md)
 - [Model.InstanceStatusLink](docs/InstanceStatusLink.md)
 - [Model.InstanceStatusStatusData](docs/InstanceStatusStatusData.md)
 - [Model.InstanceStatusStatusDataActions](docs/InstanceStatusStatusDataActions.md)
 - [Model.Message](docs/Message.md)
 - [Model.Messages](docs/Messages.md)
 - [Model.OutboundAction](docs/OutboundAction.md)
 - [Model.OutboundActions](docs/OutboundActions.md)
 - [Model.OutboundMessage](docs/OutboundMessage.md)
 - [Model.OutboundMessages](docs/OutboundMessages.md)
 - [Model.PhoneProp](docs/PhoneProp.md)
 - [Model.ReadChatAction](docs/ReadChatAction.md)
 - [Model.ReadChatStatus](docs/ReadChatStatus.md)
 - [Model.SendContactRequest](docs/SendContactRequest.md)
 - [Model.SendFileRequest](docs/SendFileRequest.md)
 - [Model.SendLinkRequest](docs/SendLinkRequest.md)
 - [Model.SendLocationRequest](docs/SendLocationRequest.md)
 - [Model.SendMessageRequest](docs/SendMessageRequest.md)
 - [Model.SendMessageStatus](docs/SendMessageStatus.md)
 - [Model.SendPTTRequest](docs/SendPTTRequest.md)
 - [Model.SendVCardRequest](docs/SendVCardRequest.md)
 - [Model.SetWebhookStatus](docs/SetWebhookStatus.md)
 - [Model.Settings](docs/Settings.md)
 - [Model.Status](docs/Status.md)
 - [Model.Statuses](docs/Statuses.md)
 - [Model.WebhookStatus](docs/WebhookStatus.md)
 - [Model.WebhookUrl](docs/WebhookUrl.md)


## Documentation for Authorization


### instanceId

- **Type**: API key

- **API key parameter name**: instanceId
- **Location**: URL query string


### token

- **Type**: API key

- **API key parameter name**: token
- **Location**: URL query string

